package com.gihon.security.controller;

import org.springframework.security.access.annotation.Secured;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 用户控制器
 * SpringSecurity中关于权限管理的注解，默认不生效。
 * 必须通过注解EnableGlobalMethodSecurity来开启，才能生效。
 * EnableGlobalMethodSecurity注解一般都定义在启动类上。也可以定义在，任意的、启动类可以扫描到的类上。
 */
@RestController
public class UserController {
    /**
     * PreAuthorize - 前置权限判断注解。注解描述的方法执行前判断认证用户是否包含权限。
     * PostAuthorize - 后置权限判断。注解描述的方法， 执行后判断认证用户是否包含权限。
     * @return
     */
    @RequestMapping("/preAuthorize")
    @PreAuthorize(value = "hasAuthority('userManagement')")
    public String preAuthorize(){
        return "前置权限判断。";
    }

    /**
     * 查看用户
     * Secured注解，相当于是定义了， antMatchers("/queryUser").hasAnyRole("管理员","超级管理员");
     * @return
     */
    @Secured(value = {"ROLE_管理员","ROLE_超级管理员"})
    @RequestMapping("/queryUser")
    public String queryUser(){
        return "queryUser";
    }
    /**
     * 增加用户
     */
    @Secured(value = {"ROLE_管理员","ROLE_超级管理员"})
    @RequestMapping("/addUser")
    public String addUser(){

        return "queryUser";
    }
}
